import { SetUserData } from "./utils/setUserData";
export declare enum AuthenticationState {
    UNAUTHENTICATED = "unauthenticated",
    AUTHENTICATED = "authenticated",
    AUTHENTICATING = "authenticating",
    LOGGING_OUT = "logging_out",
    ERROR = "error"
}
export declare type Authentication = {
    state: AuthenticationState.UNAUTHENTICATED;
    error: null;
} | {
    state: AuthenticationState.AUTHENTICATED;
    error: null;
} | {
    state: AuthenticationState.AUTHENTICATING;
    error: null;
} | {
    state: AuthenticationState.ERROR;
    error: Error;
} | {
    state: AuthenticationState.LOGGING_OUT;
    error: null;
};
export interface AuthenticateOptions {
    onError?: (error: Error) => void;
    onSuccess?: () => void;
    onComplete?: () => void;
}
export declare type Login = (username: string, password: string, options?: {
    usePost?: boolean;
}) => Promise<void>;
export declare type Signup = (username: string, password: string, email?: string, otherFields?: SetUserData) => Promise<void>;
export declare type OnAccountChanged = (account: string) => void;
export declare type AuthType = "dot" | "polkadot" | "kusama" | "erd" | "elrond";
export interface UseMoralisAuthOptions {
    onAccountChanged?: OnAccountChanged;
    authType?: AuthType;
}
/**
 * Hook that handles all authentication logic and returns the correct auth state
 * and its functions
 */
export declare const _useMoralisAuth: (options: UseMoralisAuthOptions) => {
    auth: Authentication;
    authenticate: ({ onComplete, onError, onSuccess }?: AuthenticateOptions) => Promise<void>;
    signup: Signup;
    login: Login;
    logout: () => Promise<void>;
    authError: Error | null;
    isAuthenticated: boolean;
    isUnauthenticated: boolean;
    isAuthenticating: boolean;
    hasAuthError: boolean;
    isLoggingOut: boolean;
};
